@@ -387,6 +387,30 @@ na_core_utils_slist_remove_utf8( GSList *list, const gchar *str )
 	return( list );
 }
 
+/**
+ * na_core_utils_slist_to_array:
+ * @slist: a list of strings.
+ *
+ * Returns: a newly allocated array of strings, which should be
+ * g_strfreev() by the caller.
+ */
+gchar **
+na_core_utils_slist_to_array( GSList *slist )
+{
+	GString *str;
+	GSList *is;
+	gchar **array;
+
+	str = g_string_new( "" );
+	for( is = slist ; is ; is = is->next ){
+		g_string_append_printf( str, "%s;", ( const gchar * ) is->data );
+	}
+	array = g_strsplit( str->str, ";", -1 );
+	g_string_free( str, TRUE );
+
+	return( array );
+}
+
 /**
  * na_core_utils_slist_to_text:
  * @strlist: a list of strings.
